---
description: Explore specialized Docker Hub collections like the Generative AI catalog.
keywords: Docker Hub, Hub, catalog
title: Docker Hub catalogs
linkTitle: Catalogs
weight: 60
---

Docker Hub catalogs are your go-to collections of trusted, ready-to-use
container images and resources, tailored to meet specific development needs.
They make it easier to find high-quality, pre-verified content so you can
quickly build, deploy, and manage your applications with confidence. Catalogs in
Docker Hub:

- Simplify content discovery: Organized and curated content makes it easy to
  discover tools and resources tailored to your specific domain or technology.
- Reduce complexity: Trusted resources, vetted by Docker and its partners,
  ensure security, reliability, and adherence to best practices.
- Accelerate development: Quickly integrate advanced capabilities into your
  applications without the hassle of extensive research or setup.

The generative AI catalog is the first catalog in Docker Hub, offering
specialized content for AI development.

## Generative AI catalog

The [generative AI catalog](https://hub.docker.com/catalogs/gen-ai) makes it
easy to explore and add AI capabilities to your applications. With trusted,
ready-to-use content and comprehensive documentation, you can skip the hassle of
sorting through countless tools and configurations. Instead, focus your time and
energy on creating innovative AI-powered applications.

The generative AI catalog provides a wide range of trusted content, organized
into key areas to support diverse AI development needs:

- Demos: Ready-to-deploy examples showcasing generative AI capabilities. These
  demos provide a hands-on way to explore AI tools and frameworks, making it
  easier to understand how they can be integrated into real-world applications.
- Model Context Protocol (MCP) servers: MCP servers provide reusable toolsets
  that can be used across clients, like Claude Desktop.
- Models: Pre-trained AI models for tasks like text generation,
  Natural Language Processing (NLP), and conversational AI. These models
  provide a foundation for
  AI applications without requiring developers to train models from scratch.
- Applications and end-to-end platforms: Comprehensive platforms and tools that
  simplify AI application development, including low-code solutions and
  frameworks for building multi-agent and Retrieval-Augmented Generation (RAG)
  applications.
- Model deployment and serving: Tools and frameworks that enable developers to
  efficiently deploy and serve AI models in production environments. These
  resources include pre-configured stacks for GPUs and other specialized
  hardware, ensuring performance at scale.
- Orchestration: Solutions for managing complex AI workflows, such as workflow
  engines, Large Language Model (LLM) application frameworks, and lifecycle management
  tools, to help streamline development and operations.
- Machine learning frameworks: Popular frameworks like TensorFlow and PyTorch
  that provide the building blocks for creating, training, and fine-tuning
  machine learning models.
- Databases: Databases optimized for AI workloads, including vector databases
  for similarity search, time-series databases for analytics, and NoSQL
  solutions for handling unstructured data.

> [!NOTE]
>
> For publishers, [contact us](https://www.docker.com/partners/programs/) to
> join the generative AI catalog.